@@ -1,8 +1,11 @@
-import logging
+from typing import Optional
 from abc import ABC
+import logging
 
 from pydbus.generic import signal
-from .base import NAME, INTERFACE as _INTERFACE
+
+from .base import NAME, INTERFACE as MPRIS_INTERFACE
+
 
 logger = logging.getLogger(__name__)
 
@@ -10,17 +13,17 @@ TRACE_LOG_LEVEL = 5
 
 
 class MprisInterface(ABC):
-    INTERFACE = _INTERFACE
-
-    def __init__(self,
-                 name: str = NAME,
-                 adapter: 'MprisAdapter' = None):
-        self.name = name
-        self.adapter = adapter
+    INTERFACE = MPRIS_INTERFACE
 
     PropertiesChanged = signal()
 
+    def __init__(
+      self,
+      name: str = NAME,
+      adapter: Optional['MprisAdapter'] = None
+    ):
+        self.name = name
+        self.adapter = adapter
+
     def log_trace(self, *args, **kwargs):
         logger.log(TRACE_LOG_LEVEL, *args, **kwargs)
-
-
